@@ -25,6 +25,7 @@
 #
 ##############################################################################
 import logging
+from zc.buildout import UserError
 from slapos.recipe.librecipe import wrap, JSON_SERIALISED_MAGIC_KEY
 import json
 from slapos import slap as slapmodule
@@ -33,12 +34,6 @@ import traceback
 
 DEFAULT_SOFTWARE_TYPE = 'RootSoftwareInstance'
 
-def getListOption(option_dict, key, default=()):
-  result = option_dict.get(key, default)
-  if isinstance(result, basestring):
-    result = result.split()
-  return result
-
 class Recipe(object):
   """
   Request a partition to a slap master.
@@ -104,19 +99,20 @@ class Recipe(object):
     self.logger = logging.getLogger(name)
     software_url = options['software-url']
     name = options['name']
-    return_parameters = getListOption(options, 'return')
+    return_parameters = options.get('return', '').split()
     if not return_parameters:
       self.logger.debug("No parameter to return to main instance."
         "Be careful about that...")
     software_type = options.get('software-type', DEFAULT_SOFTWARE_TYPE)
-    filter_kw = dict(
-      (x, options['sla-' + x]) for x in getListOption(options, 'sla')
-      if options['sla-' + x]
-    )
-    partition_parameter_kw = self._filterForStorage(dict(
-      (x, options['config-' + x])
-      for x in getListOption(options, 'config')
-    ))
+    if 'config' in options or 'sla' in options:
+      raise UserError("'config' & 'sla' options are obsolete."
+                      " Clean up your software release.")
+    filter_kw = {k: v
+      for k, v in options.iteritems()
+      if k.startswith('sla-') and v}
+    partition_parameter_kw = self._filterForStorage({k: v
+      for k, v in options.iteritems()
+      if k.startswith('config-')})
     slave = options.get('slave', 'false').lower() in \
       librecipe.GenericBaseRecipe.TRUE_VALUES
 
@@ -267,9 +263,8 @@ class RequestEdge(Recipe):
       # Request will have its own copy of options dict
       local_options = original_options.copy()
       local_options['name'] = '%s-%s' % (country, name)
-      local_options['sla'] = "region"
       local_options['sla-region'] = country
-      
+
       self.request_dict[country] = Recipe(buildout, name, local_options)
       # "Bubble" all connection parameters
       for option, value in local_options.iteritems():
